You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by jm...@apache.org on 2006/11/24 18:48:15 UTC

svn commit: r478931 - in /incubator/tuscany/java/spec/sca: ./ src/main/java/org/osoa/sca/annotations/

Author: jmarino
Date: Fri Nov 24 09:48:10 2006
New Revision: 478931

URL: http://svn.apache.org/viewvc?view=rev&rev=478931
Log:
rename session annotations to conversation; add EndConversation annotation

Added:
    incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Conversation.java   (contents, props changed)
      - copied, changed from r471107, incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Session.java
    incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/ConversationID.java   (contents, props changed)
      - copied, changed from r471107, incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/SessionID.java
    incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/EndConversation.java   (with props)
Removed:
    incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Session.java
    incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/SessionID.java
Modified:
    incubator/tuscany/java/spec/sca/pom.xml

Modified: incubator/tuscany/java/spec/sca/pom.xml
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sca/pom.xml?view=diff&rev=478931&r1=478930&r2=478931
==============================================================================
--- incubator/tuscany/java/spec/sca/pom.xml (original)
+++ incubator/tuscany/java/spec/sca/pom.xml Fri Nov 24 09:48:10 2006
@@ -66,7 +66,7 @@
             <groupId>junit</groupId>
             <artifactId>junit</artifactId>
             <version>3.8.1</version>
-            <scope>test</scope>
+            <scope>journalPerfTest</scope>
         </dependency>
     </dependencies>
 

Copied: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Conversation.java (from r471107, incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Session.java)
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Conversation.java?view=diff&rev=478931&p1=incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Session.java&r1=471107&p2=incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Conversation.java&r2=478931
==============================================================================
--- incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/EndConversation.java (added)
+++ incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/EndConversation.java Fri Nov 24 09:48:10 2006
@@ -0,0 +1,34 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */ 
+package org.osoa.sca.annotations;
+
+import java.lang.annotation.ElementType;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import java.lang.annotation.Target;
+
+/**
+ * Annotation used to indicate a method ends a conversation.
+ *
+ * @version $Rev$ $Date$
+ */
+@Target({ElementType.METHOD})
+@Retention(RetentionPolicy.RUNTIME)
+public @interface EndConversation {
+}

Propchange: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/EndConversation.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/EndConversation.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Session.java (original)
+++ incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Conversation.java Fri Nov 24 09:48:10 2006
@@ -24,13 +24,13 @@
 import java.lang.annotation.Target;
 
 /**
  * Annotation used to indicate the characteristics of a session.
  *
  * @version $Rev$ $Date$
  */
 @Target(TYPE)
 @Retention(RUNTIME)
-public @interface Session {
+public @interface Conversation {
     /**
      * The maximum time that can pass between operations in a single conversation.
      * If this time is exceeded the container may end the conversation.

Propchange: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Conversation.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/Conversation.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date
@@ -24,13 +24,13 @@
 
 /**
- * Annotation used to indicate the characteristics of a session.
+ * Annotation used to indicate the characteristics of a conversation.
  *
  * @version $Rev$ $Date$

Copied: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/ConversationID.java (from r471107, incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/SessionID.java)
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/ConversationID.java?view=diff&rev=478931&p1=incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/SessionID.java&r1=471107&p2=incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/ConversationID.java&r2=478931
==============================================================================
--- incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/SessionID.java (original)
+++ incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/ConversationID.java Fri Nov 24 09:48:10 2006
@@ -25,11 +25,11 @@
 import java.lang.annotation.Target;
 
 /**
  * Annotation used to indicate a field or method that is used to inject the session ID.
  *
  * @version $Rev$ $Date$
  */
 @Target({METHOD, FIELD})
 @Retention(RUNTIME)
-public @interface SessionID {
+public @interface ConversationID {
 }

Propchange: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/ConversationID.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/ConversationID.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date
@@ -25,11 +25,11 @@
 
 /**
- * Annotation used to indicate a field or method that is used to inject the session ID.
+ * Annotation used to indicate a field or method that is used to inject the conversation ID.
  *
  * @version $Rev$ $Date$

Added: incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/EndConversation.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sca/src/main/java/org/osoa/sca/annotations/EndConversation.java?view=auto&rev=478931
==============================================================================